==> simple_translate-0.1.0.tar.gz: simple_translate-0.1.0/README.md <==
#   E a s y T r a n s l a t e 
 
 
 
 T h e   ` E a s y T r a n s l a t e `   c l a s s   i s   a   P y t h o n   p a c k a g e   f o r   e a s i l y   t r a n s l a t i n g   t e x t   b e t w e e n   l a n g u a g e s   u s i n g   t h e   * * L i n g v a   A P I * * .   T h i s   c l a s s   p r o v i d e s   a   s i m p l e   i n t e r f a c e   t o   p e r f o r m   t r a n s l a t i o n s   w i t h o u t   c o m p l e x   s e t u p . 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 T o   u s e   t h e   ` E a s y T r a n s l a t e `   p a c k a g e ,   s i m p l y   i n s t a l l   i t   v i a   ` p i p ` : 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   e a s y - t r a n s l a t e 
 
 ` ` ` 
 
 
 
 # #   U s a g e 
 
 
 
 # # #   I m p o r t i n g   t h e   P a c k a g e 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   e a s y _ t r a n s l a t e   i m p o r t   E a s y T r a n s l a t e 
 
 ` ` ` 
 
 T r a n s l a t e s   t h e   p r o v i d e d   t e x t   f r o m   t h e   s o u r c e   l a n g u a g e   t o   t h e   t a r g e t   l a n g u a g e . 
 
 
 
 -   * * P a r a m e t e r s : * * 
 
     -   ` t e x t `   ( s t r ) :   T h e   t e x t   t o   b e   t r a n s l a t e d . 
 
     -   ` t a r g e t _ l a n g u a g e `   ( s t r ) :   T h e   t a r g e t   l a n g u a g e   f o r   t r a n s l a t i o n . 
 
     -   ` s o u r c e _ l a n g u a g e `   ( s t r ,   o p t i o n a l ) :   T h e   l a n g u a g e   o f   t h e   o r i g i n a l   t e x t   ( d e f a u l t   i s   ` " e n " ` ) . 
 
 
 
 -   * * R e t u r n s : * * 
 
     -   * * s t r * * :   T h e   t r a n s l a t e d   t e x t .   I f   t h e r e   i s   a n   e r r o r ,   r e t u r n s   a n   e m p t y   s t r i n g . 
 
 
 
 # #   E x a m p l e   U s a g e 
 
 
 
 # # #   E x a m p l e   1 :   T r a n s l a t e   f r o m   E n g l i s h   t o   S p a n i s h 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   e a s y _ t r a n s l a t e   i m p o r t   E a s y T r a n s l a t e 
 
 
 
 #   C r e a t e   a n   i n s t a n c e   o f   t h e   E a s y T r a n s l a t e   c l a s s 
 
 t r a n s l a t o r   =   E a s y T r a n s l a t e ( ) 
 
 
 
 #   T r a n s l a t e   f r o m   E n g l i s h   t o   S p a n i s h 
 
 t r a n s l a t e d _ t e x t   =   t r a n s l a t o r . t r a n s l a t e ( " H e l l o ,   h o w   a r e   y o u ? " ,   " e s " ,   " e n " ) 
 
 p r i n t ( t r a n s l a t e d _ t e x t )     #   O u t p u t :   " H o l a ,    c  m o   e s t  s ? " 
 
 ` ` ` 
 
 
 
 # # #   E x a m p l e   2 :   T r a n s l a t e   f r o m   F r e n c h   t o   E n g l i s h 
 
 
 
 ` ` ` p y t h o n 
 
 #   T r a n s l a t e   f r o m   F r e n c h   t o   E n g l i s h 
 
 t r a n s l a t e d _ t e x t   =   t r a n s l a t o r . t r a n s l a t e ( " B o n j o u r " ,   " e n " ,   " f r " ) 
 
 p r i n t ( t r a n s l a t e d _ t e x t )     #   O u t p u t :   " G o o d   m o r n i n g " 
 
 ` ` ` 
 
 
 
 # # #   E x a m p l e   3 :   T r a n s l a t e   f r o m   S p a n i s h   t o   E n g l i s h 
 
 
 
 ` ` ` p y t h o n 
 
 #   T r a n s l a t e   f r o m   S p a n i s h   t o   E n g l i s h 
 
 t r a n s l a t e d _ t e x t   =   t r a n s l a t o r . t r a n s l a t e ( "  C  m o   e s t  s ? " ,   " e n " ,   " e s " ) 
 
 p r i n t ( t r a n s l a t e d _ t e x t )     #   O u t p u t :   " H o w   a r e   y o u ? " 
 
 ` ` ` 
 
 
 
 # # #   E x a m p l e   4 :   G e t   S u p p o r t e d   L a n g u a g e s 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   e a s y _ t r a n s l a t e   i m p o r t   E a s y T r a n s l a t e 
 
 
 
 #   C r e a t e   a n   i n s t a n c e   o f   t h e   E a s y T r a n s l a t e   c l a s s 
 
 t r a n s l a t o r   =   E a s y T r a n s l a t e ( ) 
 
 
 
 #   G e t   t h e   l i s t   o f   s u p p o r t e d   l a n g u a g e s 
 
 l a n g u a g e s   =   t r a n s l a t o r . g e t _ s u p p o r t e d _ l a n g u a g e s ( ) 
 
 p r i n t ( l a n g u a g e s )     #   O u t p u t :   [ ' a f ' ,   ' s q ' ,   ' a m ' ,   ' a r ' ,   ' h y ' ,   . . . ] 
 
 ` ` ` 
 
 
 
 
 
 # #   E r r o r   H a n d l i n g 
 
 
 
 I f   t h e   t r a n s l a t i o n   r e q u e s t   f a i l s   d u e   t o   n e t w o r k   i s s u e s   o r   a n   i n v a l i d   r e s p o n s e ,   a   m e s s a g e   w i l l   b e   p r i n t e d   a n d   a n   e m p t y   s t r i n g   w i l l   b e   r e t u r n e d .   F o r   e x a m p l e : 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   e a s y _ t r a n s l a t e   i m p o r t   E a s y T r a n s l a t e 
 
 f r o m   r e q u e s t s . e x c e p t i o n s   i m p o r t   R e q u e s t E x c e p t i o n 
 
 
 
 t r a n s l a t o r   =   E a s y T r a n s l a t e ( ) 
 
 
 
 t r y : 
 
         t r a n s l a t e d _ t e x t   =   t r a n s l a t o r . t r a n s l a t e ( " H e l l o " ,   " f r " ,   " e n " ) 
 
         p r i n t ( t r a n s l a t e d _ t e x t ) 
 
 e x c e p t   R e q u e s t E x c e p t i o n   a s   e r r o r : 
 
         p r i n t ( f " E r r o r :   { e r r o r } " ) 
 
 ` ` ` 
 
 
 
 # #   L i c e n s e 
 
 
 
 T h i s   p a c k a g e   i s   l i c e n s e d   u n d e r   t h e   M I T   [ L i c e n s e ] ( L I C E N S E ) .   S e e   t h e   L I C E N S E   f i l e   f o r   m o r e   d e t a i l s . 
 
 

==> simple_translate-0.1.4.tar.gz: simple_translate-0.1.4/README.md <==
#   E a s y T r a n s l a t e 
 
 
 
 T h e   ` E a s y T r a n s l a t e `   c l a s s   i s   a   P y t h o n   p a c k a g e   f o r   e a s i l y   t r a n s l a t i n g   t e x t   b e t w e e n   l a n g u a g e s   u s i n g   t h e   * * L i n g v a   A P I * * .   T h i s   c l a s s   p r o v i d e s   a   s i m p l e   i n t e r f a c e   t o   p e r f o r m   t r a n s l a t i o n s   w i t h o u t   c o m p l e x   s e t u p . 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 T o   u s e   t h e   ` E a s y T r a n s l a t e `   p a c k a g e ,   s i m p l y   i n s t a l l   i t   v i a   ` p i p ` : 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   s i m p l e _ t r a n s l a t e 
 
 ` ` ` 
 
 
 
 # #   U s a g e 
 
 
 
 # # #   I m p o r t i n g   t h e   P a c k a g e 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   s i m p l e _ t r a n s l a t e   i m p o r t   E a s y T r a n s l a t e 
 
 ` ` ` 
 
 T r a n s l a t e s   t h e   p r o v i d e d   t e x t   f r o m   t h e   s o u r c e   l a n g u a g e   t o   t h e   t a r g e t   l a n g u a g e . 
 
 
 
 -   * * P a r a m e t e r s : * * 
 
     -   ` t e x t `   ( s t r ) :   T h e   t e x t   t o   b e   t r a n s l a t e d . 
 
     -   ` t a r g e t _ l a n g u a g e `   ( s t r ) :   T h e   t a r g e t   l a n g u a g e   f o r   t r a n s l a t i o n . 
 
     -   ` s o u r c e _ l a n g u a g e `   ( s t r ,   o p t i o n a l ) :   T h e   l a n g u a g e   o f   t h e   o r i g i n a l   t e x t   ( d e f a u l t   i s   ` " e n " ` ) . 
 
 
 
 -   * * R e t u r n s : * * 
 
     -   * * s t r * * :   T h e   t r a n s l a t e d   t e x t .   I f   t h e r e   i s   a n   e r r o r ,   r e t u r n s   a n   e m p t y   s t r i n g . 
 
 
 
 # #   E x a m p l e   U s a g e 
 
 
 
 # # #   E x a m p l e   1 :   T r a n s l a t e   f r o m   E n g l i s h   t o   S p a n i s h 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   s i m p l e _ t r a n s l a t e   i m p o r t   E a s y T r a n s l a t e 
 
 
 
 #   C r e a t e   a n   i n s t a n c e   o f   t h e   E a s y T r a n s l a t e   c l a s s 
 
 t r a n s l a t o r   =   E a s y T r a n s l a t e ( ) 
 
 
 
 #   T r a n s l a t e   f r o m   E n g l i s h   t o   S p a n i s h 
 
 t r a n s l a t e d _ t e x t   =   t r a n s l a t o r . t r a n s l a t e ( " H e l l o ,   h o w   a r e   y o u ? " ,   " e s " ,   " e n " ) 
 
 p r i n t ( t r a n s l a t e d _ t e x t )     #   O u t p u t :   " H o l a ,    c  m o   e s t  s ? " 
 
 ` ` ` 
 
 
 
 # # #   E x a m p l e   2 :   T r a n s l a t e   f r o m   F r e n c h   t o   E n g l i s h 
 
 
 
 ` ` ` p y t h o n 
 
 #   T r a n s l a t e   f r o m   F r e n c h   t o   E n g l i s h 
 
 t r a n s l a t e d _ t e x t   =   t r a n s l a t o r . t r a n s l a t e ( " B o n j o u r " ,   " e n " ,   " f r " ) 
 
 p r i n t ( t r a n s l a t e d _ t e x t )     #   O u t p u t :   " G o o d   m o r n i n g " 
 
 ` ` ` 
 
 
 
 # # #   E x a m p l e   3 :   T r a n s l a t e   f r o m   S p a n i s h   t o   E n g l i s h 
 
 
 
 ` ` ` p y t h o n 
 
 #   T r a n s l a t e   f r o m   S p a n i s h   t o   E n g l i s h 
 
 t r a n s l a t e d _ t e x t   =   t r a n s l a t o r . t r a n s l a t e ( "  C  m o   e s t  s ? " ,   " e n " ,   " e s " ) 
 
 p r i n t ( t r a n s l a t e d _ t e x t )     #   O u t p u t :   " H o w   a r e   y o u ? " 
 
 ` ` ` 
 
 
 
 # # #   E x a m p l e   4 :   G e t   S u p p o r t e d   L a n g u a g e s 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   s i m p l e _ t r a n s l a t e   i m p o r t   E a s y T r a n s l a t e 
 
 
 
 #   C r e a t e   a n   i n s t a n c e   o f   t h e   E a s y T r a n s l a t e   c l a s s 
 
 t r a n s l a t o r   =   E a s y T r a n s l a t e ( ) 
 
 
 
 #   G e t   t h e   l i s t   o f   s u p p o r t e d   l a n g u a g e s 
 
 l a n g u a g e s   =   t r a n s l a t o r . g e t _ s u p p o r t e d _ l a n g u a g e s ( ) 
 
 p r i n t ( l a n g u a g e s )     #   O u t p u t :   [ ' a f ' ,   ' s q ' ,   ' a m ' ,   ' a r ' ,   ' h y ' ,   . . . ] 
 
 ` ` ` 
 
 
 
 
 
 # #   E r r o r   H a n d l i n g 
 
 
 
 I f   t h e   t r a n s l a t i o n   r e q u e s t   f a i l s   d u e   t o   n e t w o r k   i s s u e s   o r   a n   i n v a l i d   r e s p o n s e ,   a   m e s s a g e   w i l l   b e   p r i n t e d   a n d   a n   e m p t y   s t r i n g   w i l l   b e   r e t u r n e d .   F o r   e x a m p l e : 
 
 
 
 ` ` ` p y t h o n 
 
 f r o m   s i m p l e _ t r a n s l a t e   i m p o r t   E a s y T r a n s l a t e 
 
 f r o m   r e q u e s t s . e x c e p t i o n s   i m p o r t   R e q u e s t E x c e p t i o n 
 
 
 
 t r a n s l a t o r   =   E a s y T r a n s l a t e ( ) 
 
 
 
 t r y : 
 
         t r a n s l a t e d _ t e x t   =   t r a n s l a t o r . t r a n s l a t e ( " H e l l o " ,   " f r " ,   " e n " ) 
 
         p r i n t ( t r a n s l a t e d _ t e x t ) 
 
 e x c e p t   R e q u e s t E x c e p t i o n   a s   e r r o r : 
 
         p r i n t ( f " E r r o r :   { e r r o r } " ) 
 
 ` ` ` 
 
 
 
 # #   L i c e n s e 
 
 
 
 T h i s   p a c k a g e   i s   l i c e n s e d   u n d e r   t h e   M I T   [ L i c e n s e ] ( L I C E N S E ) .   S e e   t h e   L I C E N S E   f i l e   f o r   m o r e   d e t a i l s . 
 
 
